svn commit: r603585 - /lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/AssertionConsumerService.java

[email protected]
Newsgroups gmane.comp.cms.lenya.cvs
Message-ID <[email protected]>
Author: andreas
Date: Wed Dec 12 04:10:33 2007
New Revision: 603585

URL: http://svn.apache.org/viewvc?rev=603585&view=rev
Log:
Fixed javadoc comments

Modified:
    lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/AssertionConsumerService.java

Modified: lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/AssertionConsumerService.java
URL: http://svn.apache.org/viewvc/lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/AssertionConsumerService.java?rev=603585&r1=603584&r2=603585&view=diff
==============================================================================
--- lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/AssertionConsumerService.java (original)
+++ lenya/branches/branch_1_2_x_shibboleth/src/java/org/apache/shibboleth/AssertionConsumerService.java Wed Dec 12 04:10:33 2007
@@ -38,7 +38,7 @@
 
     /**
      * @param req The request.
      * @param baseUrl The URL to append the shire URL to.
      * @return A browser profile response.
      * @throws SAMLException
      */
@@ -48,9 +48,9 @@
      * Uses an HTTP Status 307 redirect to forward the user the HS.
      * @param locale The locale.
      * @param idpSite The IdP site.
      * @param baseUrl The URL to append the shire URL to.
      * @return A string.
      */
-    String buildRequest(Locale locale, IdPSite idpSite, String baseUrl);
+    String buildRequest(Locale locale, IdPSite idpSite, String hostUrl);
 
 }
@@ -38,7 +38,7 @@
     /**
      * @param req The request.
-     * @param baseUrl The URL to append the shire URL to.
+     * @param hostUrl The URL to append the shire URL to.
      * @return A browser profile response.
      * @throws SAMLException
@@ -48,9 +48,9 @@
      * @param locale The locale.
      * @param idpSite The IdP site.
-     * @param baseUrl The URL to append the shire URL to.
+     * @param hostUrl The URL to append the shire URL to.
      * @return A string.
      */
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.